==> solr-api-9.6.1-sources.jar: org/apache/solr/client/api/endpoint/BalanceReplicasApi.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.solr.client.api.endpoint;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.parameters.RequestBody;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import org.apache.solr.client.api.model.BalanceReplicasRequestBody;
import org.apache.solr.client.api.model.SolrJerseyResponse;

@Path("cluster/replicas/balance")
public interface BalanceReplicasApi {
  @POST
  @Operation(
      summary = "Balance Replicas across the given set of Nodes.",
      tags = {"cluster"})
  SolrJerseyResponse balanceReplicas(
      @RequestBody(description = "Contains user provided parameters")
          BalanceReplicasRequestBody requestBody)
      throws Exception;
}

==> solr-api-10.0.0-20231106.233631-122-sources.jar: org/apache/solr/client/api/endpoint/BalanceReplicasApi.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.solr.client.api.endpoint;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.parameters.RequestBody;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import org.apache.solr.client.api.model.BalanceReplicasRequestBody;
import org.apache.solr.client.api.model.SolrJerseyResponse;

@Path("cluster/replicas/balance")
public interface BalanceReplicasApi {
  @POST
  @Operation(
      summary = "Balance Replicas across the given set of Nodes.",
      tags = {"cluster"})
  SolrJerseyResponse balanceReplicas(
      @RequestBody(description = "Contains user provided parameters")
          BalanceReplicasRequestBody requestBody)
      throws Exception;
}
